"use client";

import { useEffect, useState, FormEvent } from "react";
import { DateRangePicker } from "react-date-range";
import "react-date-range/dist/styles.css";
import "react-date-range/dist/theme/default.css";
import { format } from "date-fns";
import * as XLSX from "xlsx";
import { ar } from "date-fns/locale";

type Question = {
  id: string;
  label: string;
  type: string;
  required: boolean;
  options?: string[];
};

type AnswersItem = {
  label: string;
  value: string;
};

type SubmissionData = {
  _id: string;
  answersArray: AnswersItem[];
  cvFilePath: string;
  createdAt: string;
};

export default function CVSearchPage() {
  const [questions, setQuestions] = useState<Question[]>([]);
  const [selectQuestions, setSelectQuestions] = useState<Question[]>([]);
  const [submissions, setSubmissions] = useState<SubmissionData[]>([]);
  const [loading, setLoading] = useState(false);
  const [searchText, setSearchText] = useState("");
  const [selectValues, setSelectValues] = useState<Record<string, string>>({});
  const [dateRange, setDateRange] = useState<{ start: string; end: string }>({
    start: "",
    end: "",
  });
  const [currentPage, setCurrentPage] = useState(1);
  const [totalPages, setTotalPages] = useState(1);
  const [totalResults, setTotalResults] = useState(0);
  const [showDatePicker, setShowDatePicker] = useState(false);

  useEffect(() => {
    fetch("/api/form")
      .then((res) => res.json())
      .then((data) => {
        if (data && !data.error) {
          const qs: Question[] = data.questions || []; // Ensure `qs` is typed as `Question[]`
          setQuestions(qs);
  
          const selects = qs.filter((q: Question) => q.type === "select"); // Explicitly type `q` as `Question`
          setSelectQuestions(selects);
  
          const initObj: Record<string, string> = {};
          for (const sq of selects) {
            initObj[sq.id] = "";
          }
          setSelectValues(initObj);
        }
      })
      .catch(console.error);
  
    fetchSubmissions();
  }, []);

  async function fetchSubmissions(filters?: Record<string, string>) {
    setLoading(true);
    try {
      let url = `/api/submissions?page=${currentPage}&limit=20`;
      const queryParams: string[] = [];

      if (filters) {
        for (const [key, value] of Object.entries(filters)) {
          if (value) {
            queryParams.push(`${encodeURIComponent(key)}=${encodeURIComponent(value)}`);
          }
        }
      }

      if (searchText.trim()) {
        queryParams.push(`search=${encodeURIComponent(searchText.trim())}`);
      }

      if (dateRange.start && dateRange.end) {
        queryParams.push(
          `startDate=${encodeURIComponent(dateRange.start)}`,
          `endDate=${encodeURIComponent(dateRange.end)}`
        );
      }

      if (queryParams.length > 0) {
        url += `&${queryParams.join("&")}`;
      }

      const res = await fetch(url);
      if (!res.ok) {
        throw new Error("Failed to fetch submissions");
      }
      const data = await res.json();
      setSubmissions(data.submissions || []);
      setTotalPages(data.totalPages || 1);
      setTotalResults(data.totalResults || 0);
    } catch (err: any) {
      console.error("Error fetching submissions:", err);
      alert("حدث خطأ أثناء جلب السير الذاتية.");
    } finally {
      setLoading(false);
    }
  }

  const exportAllAsXLSX = async () => {
    if (!totalResults) {
      alert("لا توجد بيانات للتصدير.");
      return;
    }
  
    try {
      // Fetch all submissions matching the current filters
      const queryParams: string[] = [];
      if (searchText.trim()) {
        queryParams.push(`search=${encodeURIComponent(searchText.trim())}`);
      }
  
      if (dateRange.start && dateRange.end) {
        queryParams.push(
          `startDate=${encodeURIComponent(dateRange.start)}`,
          `endDate=${encodeURIComponent(dateRange.end)}`
        );
      }
  
      for (const [key, value] of Object.entries(selectValues)) {
        if (value) {
          queryParams.push(`${encodeURIComponent(key)}=${encodeURIComponent(value)}`);
        }
      }
  
      const url = `/api/submissions?limit=${totalResults}&${queryParams.join("&")}`;
      const res = await fetch(url);
      if (!res.ok) {
        throw new Error("Failed to fetch all submissions for export.");
      }
  
      const data = await res.json();
      const submissions = data.submissions || [];
  
      if (!submissions.length) {
        alert("لا توجد بيانات للتصدير.");
        return;
      }
  
      // Prepare data for Excel
      const dataForExcel = submissions.map((sub: SubmissionData) => {
        const row: Record<string, any> = {};
  
        questions.forEach((q) => {
          const answer = sub.answersArray.find((a) => a.label === q.label);
          row[q.label] = answer?.value || "غير متوفر";
        });
  
        row["تاريخ الإرسال"] = new Date(sub.createdAt).toLocaleDateString("ar-EG");
        row["CV Link"] = {
          t: "s",
          v: "رابط",
          l: { Target: `${window.location.origin}/api/files/${sub.cvFilePath}` },
        };
  
        return row;
      });
  
      // Generate Excel file
      const ws = XLSX.utils.json_to_sheet(dataForExcel);
      ws["!cols"] = [
        ...questions.map(() => ({ wch: 20 })), // Adjust column width
        { wch: 15 },
        { wch: 10 },
      ];
  
      const wb = XLSX.utils.book_new();
      XLSX.utils.book_append_sheet(wb, ws, "Submissions");
      XLSX.writeFile(wb, "submissions.xlsx");
  
      alert("تم تصدير النتائج بنجاح!");
    } catch (error) {
      console.error("Error exporting submissions:", error);
      alert("حدث خطأ أثناء تصدير النتائج.");
    }
  };

  const handleSelectChange = (questionId: string, value: string) => {
    setSelectValues((prev) => ({
      ...prev,
      [questionId]: value,
    }));
  };

  const handleSearch = (e: FormEvent) => {
    e.preventDefault();

    const filters: Record<string, string> = {};
    for (const [key, value] of Object.entries(selectValues)) {
      if (value) {
        filters[key] = value;
      }
    }

    fetchSubmissions(filters);
  };

  const handlePageChange = (newPage: number) => {
    setCurrentPage(newPage);
    fetchSubmissions({
      ...selectValues,
      search: searchText.trim(),
      startDate: dateRange.start,
      endDate: dateRange.end,
    });
  };

  useEffect(() => {
    fetchSubmissions({
      ...selectValues,
      search: searchText.trim(),
      startDate: dateRange.start,
      endDate: dateRange.end,
    });
  }, [currentPage]);

  return (
    <div className="container mt-5" dir="rtl">
      <h1 className="text-primary fw-bold mb-4">البحث في السير الذاتية</h1>

      <div className="mb-4">
        <button onClick={exportAllAsXLSX} className="btn btn-primary">
          تصدير جميع النتائج
        </button>
      </div>

      <form onSubmit={handleSearch}>
        <div className="row g-2 align-items-center mb-3">
          <div className="col-md-8">
            <input
              type="text"
              placeholder="بحث..."
              className="form-control form-control-sm"
              value={searchText}
              onChange={(e) => setSearchText(e.target.value)}
            />
          </div>
          <div className="col-md-4">
            <button type="submit" className="btn btn-primary btn-sm">
              بحث
            </button>
          </div>
        </div>

        <div className="row g-2 align-items-center mb-3">
          <div className="col-md-12">
            <button
              type="button"
              className="btn btn-outline-primary"
              onClick={() => setShowDatePicker((prev) => !prev)}
            >
              اختر النطاق الزمني
            </button>
          </div>
        </div>

        {showDatePicker && (
          <div className="mb-4" style={{ maxWidth: "300px", direction: "rtl" }}>
            <DateRangePicker
              ranges={[
                {
                  startDate: new Date(dateRange.start || Date.now()),
                  endDate: new Date(dateRange.end || Date.now()),
                  key: "selection",
                },
              ]}
              onChange={(ranges) => {
                const { startDate, endDate } = ranges.selection;
              
                setDateRange({
                  start: format(startDate || new Date(), "yyyy-MM-dd"), // Use `new Date()` as a fallback
                  end: format(endDate || new Date(), "yyyy-MM-dd"),     // Use `new Date()` as a fallback
                });
              }}
              locale={ar}
              months={1}
              direction="horizontal"
              showDateDisplay={false}
            />
          </div>
        )}

        <div className="row g-2">
          {selectQuestions.map((sq) => (
            <div className="col-md-2" key={sq.id}>
              <select
                className="form-select form-select-sm"
                value={selectValues[sq.id] || ""}
                onChange={(e) => handleSelectChange(sq.id, e.target.value)}
              >
                <option value="">{sq.label}</option>
                {sq.options?.map((opt) => (
                  <option key={opt} value={opt}>
                    {opt}
                  </option>
                ))}
              </select>
            </div>
          ))}
        </div>
      </form>

      <p>عدد النتائج: {totalResults}</p>

      {loading ? (
        <p>جارٍ التحميل...</p>
      ) : submissions.length > 0 ? (
        <div>
          <table className="table table-bordered">
            <thead>
              <tr>
                {questions.map((q) => (
                  <th key={q.id}>{q.label}</th>
                ))}
                <th>تاريخ الإرسال</th>
                <th>رابط ال CV</th>
                <th>إجراءات</th>
              </tr>
            </thead>
            <tbody>
              {submissions.map((sub) => (
                <tr key={sub._id}>
                  {questions.map((q) => {
                    const ansItem = sub.answersArray.find(
                      (item) => item.label.toLowerCase() === q.label.toLowerCase()
                    );
                    return <td key={q.id}>{ansItem ? ansItem.value : "غير متوفر"}</td>;
                  })}
                  <td>{new Date(sub.createdAt).toLocaleDateString("ar-EG")}</td>
                  <td>
                    <a
                      href={`/api/files/${encodeURIComponent(sub.cvFilePath)}`}
                      target="_blank"
                      rel="noopener noreferrer"
                      className="btn btn-success btn-sm"
                    >
                      تحميل
                    </a>
                  </td>
                  <td>
                    <button
                      className="btn btn-primary btn-sm"
                      onClick={() => window.open(`/api/files/${encodeURIComponent(sub.cvFilePath)}`, "_blank")}
                    >
                      عرض
                    </button>
                  </td>
                </tr>
              ))}
            </tbody>
          </table>

          <div className="d-flex justify-content-center">
            {Array.from({ length: totalPages }).map((_, index) => (
              <button
                key={index}
                className={`btn btn-sm ${
                  index + 1 === currentPage ? "btn-primary" : "btn-outline-primary"
                } mx-1`}
                onClick={() => handlePageChange(index + 1)}
              >
                {index + 1}
              </button>
            ))}
          </div>
        </div>
      ) : (
        <p>لم يتم العثور على نتائج.</p>
      )}
    </div>
  );
}
