"use client";

import { useEffect, useState } from "react";

type Question = {
  id: string;
  label: string;
  type: string;
  required: boolean;
  options: string[];
};

export default function FormBuilderPageClient({ session }: { session: any }) {
  const [title, setTitle] = useState("إنشاء نموذج جديد");
  const [questions, setQuestions] = useState<Question[]>([]);

  useEffect(() => {
    fetch("/api/form")
      .then((res) => res.json())
      .then((data) => {
        if (data && !data.error) {
          setTitle(data.title || "إنشاء نموذج جديد");
          setQuestions(data.questions || []);
        }
      })
      .catch((err) => console.error("Error fetching form definition:", err));
  }, []);

  function addQuestion() {
    setQuestions((prev) => [
      ...prev,
      {
        id: Date.now().toString(),
        label: "سؤال جديد",
        type: "text",
        required: false,
        options: [],
      },
    ]);
  }

  function removeQuestion(id: string) {
    setQuestions((prev) => prev.filter((q) => q.id !== id));
  }

  function updateQuestion(id: string, field: keyof Question, value: any) {
    setQuestions((prev) =>
      prev.map((q) =>
        q.id === id
          ? { ...q, [field]: value }
          : q
      )
    );
  }

  async function saveForm() {
    try {
      const res = await fetch("/api/form", {
        method: "PUT",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({
          title,
          questions,
          user: session.user.username,
          ip: session.user.ip || "Unknown",
        }),
      });
      if (!res.ok) {
        throw new Error("Failed to save form");
      }
      alert("تم حفظ النموذج بنجاح!");
    } catch (error) {
      console.error(error);
      alert("حدث خطأ أثناء حفظ النموذج.");
    }
  }

  return (
    <div className="container mt-5" dir="rtl">
      <div className="row">
        <div className="col-lg-8 mx-auto">
          <h1 className="text-primary fw-bold mb-4">{title}</h1>
          <div className="mb-4">
            <label className="form-label">عنوان النموذج</label>
            <input
              value={title}
              onChange={(e) => setTitle(e.target.value)}
              className="form-control"
              placeholder="أدخل عنوان النموذج"
            />
          </div>

          {questions.map((q, index) => (
            <div key={q.id} className="card mb-3 shadow-sm">
              <div className="card-body">
                <div className="mb-3">
                  <label className="form-label">نص السؤال</label>
                  <input
                    value={q.label}
                    onChange={(e) => updateQuestion(q.id, "label", e.target.value)}
                    className="form-control"
                    placeholder="أدخل نص السؤال"
                  />
                </div>

                <div className="mb-3">
                  <label className="form-label">نوع السؤال</label>
                  <select
                    value={q.type}
                    onChange={(e) => updateQuestion(q.id, "type", e.target.value)}
                    className="form-select"
                  >
                    <option value="text">نص</option>
                    <option value="textarea">مربع نصي</option>
                    <option value="select">قائمة منسدلة</option>
                  </select>
                </div>

                <div className="mb-3">
                  <label className="form-check-label">هل السؤال مطلوب؟</label>
                  <input
                    type="checkbox"
                    className="form-check-input ms-2"
                    checked={q.required}
                    onChange={(e) => updateQuestion(q.id, "required", e.target.checked)}
                  />
                </div>

                {q.type === "select" && (
                  <div className="mb-3">
                    <label className="form-label">الخيارات (افصلها بفاصلة)</label>
                    <input
                      value={q.options.join(",")}
                      onChange={(e) =>
                        updateQuestion(q.id, "options", e.target.value.split(",").map((opt) => opt.trim()))
                      }
                      className="form-control"
                      placeholder="أدخل الخيارات"
                    />
                  </div>
                )}

                <button
                  className="btn btn-danger"
                  onClick={() => removeQuestion(q.id)}
                >
                  حذف السؤال
                </button>
              </div>
            </div>
          ))}

          <div className="d-flex justify-content-between">
            <button
              type="button"
              onClick={addQuestion}
              className="btn btn-success"
            >
              إضافة سؤال
            </button>
            <button
              type="button"
              onClick={saveForm}
              className="btn btn-primary"
            >
              حفظ النموذج
            </button>
          </div>
        </div>
      </div>
    </div>
  );
}
