"use client";

import { useEffect, useState } from "react";
import { saveAs } from "file-saver";

type Log = {
  _id: string;
  action: string;
  user: string;
  ip: string;
  createdAt: string;
  details: Record<string, any>;
};

export default function LogsPage() {
  const [logs, setLogs] = useState<Log[]>([]);
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    setLoading(true);
    fetch("/api/logs")
      .then((res) => res.json())
      .then((data) => {
        if (data && Array.isArray(data)) {
          setLogs(data);
        }
      })
      .catch((err) => console.error("Error fetching logs:", err))
      .finally(() => setLoading(false));
  }, []);

  const formatDetails = (details: Record<string, any>): string => {
    if (!details || Object.keys(details).length === 0) {
      return "لا توجد تفاصيل";
    }
    return Object.entries(details)
      .map(([key, value]) => `${key}: ${value}`)
      .join(", ");
  };

  const exportLogsAsCSV = () => {
    if (!logs.length) {
      alert("لا توجد سجلات للتصدير.");
      return;
    }

    const csvContent =
      "data:text/csv;charset=utf-8," +
      [
        ["الإجراء", "المستخدم", "عنوان الـIP", "التوقيت", "معلومات إضافية"],
        ...logs.map((log) => [
          log.action,
          log.user || "مستخدم مجهول",
          log.ip || "غير معروف",
          new Date(log.createdAt).toLocaleString(),
          formatDetails(log.details),
        ]),
      ]
        .map((row) => row.join(","))
        .join("\n");

    const encodedUri = encodeURI(csvContent);
    const link = document.createElement("a");
    link.setAttribute("href", encodedUri);
    link.setAttribute("download", "logs.csv");
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  };

  return (
    <div className="container mt-5" dir="rtl">
      <h1 className="text-primary fw-bold mb-4">السجلات</h1>
      <div className="d-flex justify-content-between align-items-center mb-4">
        <button
          className="btn btn-primary"
          onClick={exportLogsAsCSV}
        >
          تصدير السجلات  
        </button>
      </div>
      {loading ? (
        <p>جارٍ التحميل...</p>
      ) : logs.length > 0 ? (
        <table className="table table-bordered">
          <thead>
            <tr>
              <th>الإجراء</th>
              <th>المستخدم</th>
              <th>عنوان الـIP</th>
              <th>التوقيت</th>
              <th>معلومات إضافية</th>
            </tr>
          </thead>
          <tbody>
            {logs.map((log) => (
              <tr key={log._id}>
                <td>{log.action}</td>
                <td>{log.user || "مستخدم مجهول"}</td>
                <td>{log.ip || "غير معروف"}</td>
                <td>{new Date(log.createdAt).toLocaleString()}</td>
                <td>{formatDetails(log.details)}</td>
              </tr>
            ))}
          </tbody>
        </table>
      ) : (
        <p>لا توجد سجلات متاحة.</p>
      )}
    </div>
  );
}
