"use client";

import { useEffect, useState } from "react";

type User = {
  _id: string;
  username: string;
  role: string;
  permissions: { formBuilder: boolean };
};

export default function UserManagementPage() {
  const [users, setUsers] = useState<User[]>([]);
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [formBuilder, setFormBuilder] = useState(false);

  useEffect(() => {
    fetchUsers();
  }, []);

  async function fetchUsers() {
    try {
      const res = await fetch("/api/users");
      const data = await res.json();
      setUsers(data);
    } catch (err) {
      console.error("Failed to fetch users", err);
    }
  }

  async function handleCreateUser() {
    try {
      const res = await fetch("/api/users", {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ username, password, permissions: { formBuilder } }),
      });
      if (!res.ok) throw new Error("Failed to create user");
      alert("تم إنشاء المستخدم بنجاح!");
      setUsername("");
      setPassword("");
      setFormBuilder(false);
      fetchUsers();
    } catch (err) {
      alert("حدث خطأ أثناء إنشاء المستخدم.");
    }
  }

  async function handleDeleteUser(userId: string) {
    if (!confirm("هل أنت متأكد أنك تريد حذف هذا المستخدم؟")) return;

    try {
      const res = await fetch("/api/users", {
        method: "DELETE",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ userId }),
      });
      if (!res.ok) throw new Error("Failed to delete user");
      alert("تم حذف المستخدم بنجاح!");
      fetchUsers();
    } catch (err) {
      alert("حدث خطأ أثناء حذف المستخدم.");
    }
  }

  async function handleEditUser(user: User) {
    const newPermissions = prompt(
      "تحديث الصلاحيات (بتنسيق JSON، مثال: {\"formBuilder\": true}):",
      JSON.stringify(user.permissions)
    );

    if (!newPermissions) return;

    let parsedPermissions;
    try {
      parsedPermissions = JSON.parse(newPermissions);
    } catch {
      alert("تنسيق JSON غير صالح.");
      return;
    }

    try {
      const res = await fetch("/api/users", {
        method: "PUT",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify({ userId: user._id, permissions: parsedPermissions }),
      });
      if (!res.ok) throw new Error("Failed to update user");
      alert("تم تحديث المستخدم بنجاح!");
      fetchUsers();
    } catch (err) {
      alert("حدث خطأ أثناء تحديث المستخدم.");
    }
  }

  return (
    <div className="container mt-5" dir="rtl">
      <h1 className="text-primary fw-bold mb-4">إدارة المستخدمين</h1>
      <div className="mb-4">
        <h2 className="text-xl font-semibold mb-3">إضافة مستخدم جديد</h2>
        <div className="row g-3">
          <div className="col-md-4">
            <input
              type="text"
              placeholder="اسم المستخدم"
              value={username}
              onChange={(e) => setUsername(e.target.value)}
              className="form-control"
            />
          </div>
          <div className="col-md-4">
            <input
              type="password"
              placeholder="كلمة المرور"
              value={password}
              onChange={(e) => setPassword(e.target.value)}
              className="form-control"
            />
          </div>
          <div className="col-md-4 d-flex align-items-center">
            <label className="form-check-label me-2">الوصول إلى منشئ النماذج</label>
            <input
              type="checkbox"
              checked={formBuilder}
              onChange={(e) => setFormBuilder(e.target.checked)}
              className="form-check-input"
            />
          </div>
        </div>
        <button onClick={handleCreateUser} className="btn btn-primary mt-3">
          إضافة مستخدم
        </button>
      </div>

      <h2 className="text-xl font-semibold mb-3">المستخدمون الحاليون</h2>
      {users.length > 0 ? (
        <table className="table table-bordered">
          <thead>
            <tr>
              <th>اسم المستخدم</th>
              <th>الدور</th>
              <th>صلاحيات منشئ النماذج</th>
              <th>إجراءات</th>
            </tr>
          </thead>
          <tbody>
            {users.map((user) => (
              <tr key={user._id}>
                <td>{user.username}</td>
                <td>{user.role}</td>
                <td>{user.permissions.formBuilder ? "نعم" : "لا"}</td>
                <td>
                  {user.role !== "superadmin" ? (
                    <>
                      <button
                        onClick={() => handleEditUser(user)}
                        className="btn btn-warning btn-sm me-2"
                      >
                        تعديل
                      </button>
                      <button
                        onClick={() => handleDeleteUser(user._id)}
                        className="btn btn-danger btn-sm"
                      >
                        حذف
                      </button>
                    </>
                  ) : (
                    <span className="text-muted">لا يمكن تعديل أو حذف المدير العام</span>
                  )}
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      ) : (
        <p>لا يوجد مستخدمون حاليًا.</p>
      )}
    </div>
  );
}
