import { NextRequest, NextResponse } from "next/server";
import { connectToDB } from "../../lib/db";
import FormDefinition from "../../lib/models/FormDefinition";
import { logAction } from "../../lib/utils/logAction";
import { getServerSession } from "next-auth";
import { authOptions } from "../../../utils/authOptions"; // Adjust the path if needed

export async function GET() {
  try {
    await connectToDB();
    let formDef = await FormDefinition.findOne();
    if (!formDef) {
      // If no form definition exists, create a default
      formDef = await FormDefinition.create({
        title: "CV Submission Form",
        questions: [],
      });
    }
    return NextResponse.json(formDef);
  } catch (error: any) {
    console.error("GET /api/form error:", error);
    return NextResponse.json({ error: error.message }, { status: 500 });
  }
}

export async function PUT(req: NextRequest) {
  try {
    await connectToDB();

    // Get session to extract authenticated user
    const session = await getServerSession(authOptions);

    // Debug the session object to verify username
    console.log("Session Object:", session);

    // Extract data from the request body
    const { title, questions, ip } = await req.json();

    // Use the session username or fallback to "Unknown User"
    const user = session?.user?.username || "Unknown User";

    let formDef = await FormDefinition.findOne();
    if (!formDef) {
      // Create a new form definition if none exists
      formDef = await FormDefinition.create({ title, questions });
    } else {
      // Update the existing form definition
      formDef.title = title;
      formDef.questions = questions;
      await formDef.save();
    }

    // Log the action with the correct username
    await logAction({
      action: "FORM_UPDATED",
      user,
      ip: ip || "Unknown",
      details: { title, questionsCount: questions.length },
    });

    return NextResponse.json({ success: true, formDef });
  } catch (error: any) {
    console.error("PUT /api/form error:", error);
    return NextResponse.json({ error: error.message }, { status: 500 });
  }
}
