import { NextRequest, NextResponse } from "next/server";
import { connectToDB } from "../../lib/db";
import Submission from "../../lib/models/Submission";
import FormDefinition from "../../lib/models/FormDefinition";
import Log from "../../lib/models/Log";
import nodemailer from "nodemailer";

import fs from "fs";
import path from "path";
import crypto from "crypto";

const PDF_MAGIC_BYTES = Buffer.from([0x25, 0x50, 0x44, 0x46]); // %PDF

// Helper function for rate limiting
const submissionTimes: { [ip: string]: number } = {};

function checkRateLimit(ip: string, timeLimit: number): boolean {
  const currentTime = Date.now();
  if (submissionTimes[ip] && currentTime - submissionTimes[ip] < timeLimit) {
    return false;
  }
  submissionTimes[ip] = currentTime;
  return true;
}

export async function GET(req: NextRequest) {
  try {
    await connectToDB();

    const queryParams = Object.fromEntries(req.nextUrl.searchParams.entries());
    const page = parseInt(queryParams.page || "1", 10);
    const limit = parseInt(queryParams.limit || "20", 10);
    const startDate = queryParams.startDate || null;
    const endDate = queryParams.endDate || null;

    let filter: any = {};

    // Add date range filter if provided
    if (startDate && endDate) {
      filter.createdAt = {
        $gte: new Date(startDate),
        $lte: new Date(endDate),
      };
    }

    // Parse field-specific filters
    for (const [key, value] of Object.entries(queryParams)) {
      if (["page", "limit", "startDate", "endDate", "search"].includes(key)) continue;

      const formDef = await FormDefinition.findOne();
      if (!formDef) {
        return NextResponse.json({ error: "No form definition found" }, { status: 400 });
      }

      const question = formDef.questions.find((q) => q.id === key);
      if (question) {
        filter["answersArray"] = {
          ...filter["answersArray"],
          $elemMatch: { label: question.label, value },
        };
      }
    }

    // Add general search filter
    if (queryParams.search) {
      filter["answersArray.value"] = { $regex: queryParams.search, $options: "i" };
    }

    const totalResults = await Submission.countDocuments(filter);
    const totalPages = Math.ceil(totalResults / limit);

    const submissions = await Submission.find(filter)
      .sort({ createdAt: -1 })
      .skip((page - 1) * limit)
      .limit(limit)
      .select("_id answersArray cvFilePath createdAt")
      .lean();

    return NextResponse.json({
      submissions,
      totalResults,
      totalPages,
    });
  } catch (err: any) {
    console.error("Error in GET /api/submissions:", err);
    return NextResponse.json({ error: err.message }, { status: 500 });
  }
}

export async function POST(req: NextRequest) {
  try {
    const ip = req.headers.get("x-forwarded-for") || "127.0.0.1";

    // Prevent multiple submissions within 2 hours
    if (!checkRateLimit(ip.toString(), 2 * 60 * 60 * 1000)) {
      return NextResponse.json(
        { error: "لا يمكنك التقديم مجدداً , يمكنك المحاولة مره أخري لاحقاً" },
        { status: 429 }
      );
    }

    const formData = await req.formData();
    const file = formData.get("cvFile") as File | null;

    // Check if file exists and is a PDF
    if (!file || !file.name.endsWith(".pdf")) {
      return NextResponse.json({ error: "الرجاء رفع ملف PDF فقط" }, { status: 400 });
    }

    const arrayBuffer = await file.arrayBuffer();
    const buffer = Buffer.from(arrayBuffer);

    // Validate file as PDF using magic bytes
    if (!buffer.slice(0, 4).equals(PDF_MAGIC_BYTES)) {
      return NextResponse.json({ error: "الملف المرفق ليس بصيغة PDF" }, { status: 400 });
    }

    await connectToDB();

    const formDef = await FormDefinition.findOne();
    if (!formDef) {
      return NextResponse.json({ error: "لا يوجد تعريف للنموذج" }, { status: 400 });
    }

    const answersArray: Array<{ label: string; value: string }> = [];
    for (const q of formDef.questions) {
      const userInput = formData.get(q.id);
      const value = typeof userInput === "string" ? userInput.substring(0, 255) : "";
      answersArray.push({ label: q.label, value });
    }

    const randomFileName = crypto.randomUUID() + ".pdf";
    const dir = path.join(process.cwd(), "data");
    if (!fs.existsSync(dir)) {
      fs.mkdirSync(dir, { recursive: true });
    }
    const fullPath = path.join(dir, randomFileName);
    fs.writeFileSync(fullPath, buffer);

    const newSubmission = await Submission.create({
      answersArray,
      cvFilePath: randomFileName,
      createdAt: new Date(),
    });

    await Log.create({
      action: "SUBMISSION_CREATED",
      details: {
        submissionId: newSubmission._id.toString(),
        ip: ip.toString(),
      },
    });

    const emailEntry = answersArray.find((ans) => ans.value.includes("@"));
    if (emailEntry && process.env.EmailNotify?.toLowerCase() === "true") {
      const transporter = nodemailer.createTransport({
        host: process.env.SMTP_HOST,
        port: parseInt(process.env.SMTP_PORT || "587", 10),
        secure: false, // true for 465, false for other ports
        auth: {
          user: process.env.EMAIL_USER,
          pass: process.env.EMAIL_PASS,
        },
      });
    
      const emailMessage = `
        السلام عليكم،
    
        شكرًا لتقديم سيرتك الذاتية في موقع "مورد". تم استلام طلبك بنجاح وسيتم مراجعته قريبًا.
    
        إذا كانت لديك أي استفسارات، يمكنك التواصل معنا عبر البريد الإلكتروني:
        info@mawrd.com
    
        مع أطيب التحيات،
        فريق عمل مورد
      `;
    
      try {
        await transporter.sendMail({
          from: `"مورد" <${process.env.EMAIL_USER}>`,
          to: emailEntry.value,
          subject: "تم استلام طلب السيرة الذاتية الخاص بك",
          text: emailMessage,
          html: `<p>${emailMessage.replace(/\n/g, "<br>")}</p>`,
        });
      } catch (error) {
        console.error("Error sending email:", error);
      }
    } else if (process.env.EmailNotify?.toLowerCase() !== "true") {
      console.log("Email notifications are turned off. No email sent.");
    }
    
    
    return NextResponse.json({
      success: true,
      message: "تم تقديم الطلب بنجاح",
      submissionId: newSubmission._id,
    });
  } catch (err: any) {
    console.error("Error in POST /api/submissions:", err);
    return NextResponse.json({ error: err.message }, { status: 500 });
  }
}
