import { NextResponse } from "next/server";
import { getServerSession } from "next-auth";
import { authOptions } from "../../../utils/authOptions"; // Adjust the path if needed
import { connectToDB } from "../../lib/db";
import User from "../../lib/models/User";
import bcrypt from "bcrypt"; // Ensure compatibility with bcrypt

// Middleware for superadmin check
async function isSuperAdmin(req: Request) {
  const session = await getServerSession(authOptions);

  if (!session || session.user.role !== "superadmin") {
    return false;
  }
  return true;
}

// Create User
export async function POST(req: Request) {
  try {
    if (!(await isSuperAdmin(req))) {
      return NextResponse.json({ error: "Unauthorized" }, { status: 403 });
    }

    const { username, password, permissions } = await req.json();
    const hashedPassword = await bcrypt.hash(password, 10);

    await connectToDB();
    const newUser = new User({
      username,
      password: hashedPassword,
      role: "admin", // Default role is admin
      permissions,
    });

    await newUser.save();
    return NextResponse.json({ message: "User created successfully" });
  } catch (err) {
    console.error("Error creating user:", err);
    return NextResponse.json({ error: "Failed to create user" }, { status: 500 });
  }
}

// Get All Users (Superadmin Only)
export async function GET(req: Request) {
  try {
    if (!(await isSuperAdmin(req))) {
      return NextResponse.json({ error: "Unauthorized" }, { status: 403 });
    }

    await connectToDB();
    const users = await User.find({}, { password: 0 }); // Exclude passwords
    return NextResponse.json(users);
  } catch (err) {
    console.error("Error fetching users:", err);
    return NextResponse.json({ error: "Failed to fetch users" }, { status: 500 });
  }
}

// Update User Permissions and Role
export async function PUT(req: Request) {
  try {
    if (!(await isSuperAdmin(req))) {
      return NextResponse.json({ error: "Unauthorized" }, { status: 403 });
    }

    const { userId, permissions, role } = await req.json();

    await connectToDB();

    // Find the user to check their role
    const user = await User.findById(userId);
    if (!user) {
      return NextResponse.json({ error: "User not found" }, { status: 404 });
    }

    // Prevent editing the superadmin
    if (user.role === "superadmin") {
      return NextResponse.json({ error: "Cannot edit superadmin" }, { status: 403 });
    }

    // Update permissions and role if provided
    if (permissions) user.permissions = permissions;
    if (role && role !== "superadmin") user.role = role;

    await user.save();
    return NextResponse.json({ message: "User updated successfully" });
  } catch (err) {
    console.error("Error updating user:", err);
    return NextResponse.json({ error: "Failed to update user" }, { status: 500 });
  }
}

// Delete User
export async function DELETE(req: Request) {
  try {
    if (!(await isSuperAdmin(req))) {
      return NextResponse.json({ error: "Unauthorized" }, { status: 403 });
    }

    const { userId } = await req.json();

    await connectToDB();

    // Find the user to check their role
    const user = await User.findById(userId);
    if (!user) {
      return NextResponse.json({ error: "User not found" }, { status: 404 });
    }

    // Prevent deleting the superadmin
    if (user.role === "superadmin") {
      return NextResponse.json({ error: "Cannot delete superadmin" }, { status: 403 });
    }

    await User.findByIdAndDelete(userId);
    return NextResponse.json({ message: "User deleted successfully" });
  } catch (err) {
    console.error("Error deleting user:", err);
    return NextResponse.json({ error: "Failed to delete user" }, { status: 500 });
  }
}
