'use client';
import { useState, useEffect, FormEvent } from "react";
import Layout from "@/components/layout/Layout";

type Question = {
  id: string;
  label: string;
  type: string;
  required: boolean;
  options?: string[];
};

export default function SubmitCVPage() {
  const [title, setTitle] = useState("Job Application");
  const [questions, setQuestions] = useState<Question[]>([]);
  const [file, setFile] = useState<File | null>(null);
  const [message, setMessage] = useState<string | null>(null);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    fetch("/api/form")
      .then((res) => res.json())
      .then((data) => {
        if (data && !data.error) {
          setTitle(data.title || "Job Application");
          setQuestions(data.questions || []);
        }
      })
      .catch((err) => console.error("Error fetching form definition:", err));
  }, []);

  async function handleSubmit(e: FormEvent<HTMLFormElement>) {
    e.preventDefault();

    const formData = new FormData(e.currentTarget);
    if (file) {
      formData.append("cvFile", file);
    }

    try {
      const response = await fetch("/api/submissions", {
        method: "POST",
        body: formData,
      });

      if (!response.ok) {
        const errData = await response.json();
        setError(errData.error || "حدث خطأ أثناء التقديم");
        return;
      }

      const data = await response.json();
      setMessage(data.message || "تم التقديم بنجاح");
      setTimeout(() => {
        window.location.href = "/";
      }, 3000);
    } catch (err: any) {
      setError(err.message || "حدث خطأ أثناء التقديم");
    }
  }

  return (
    <>
      <Layout headerStyle={1} footerStyle={1} breadcrumbTitle={title}>
        <div className="main-contact-form section-padding bg-light">
          <div className="container">
            <div className="row">
              <div className="col-lg-8 m-auto">
                <div className="form-container card shadow-sm p-4 rounded">
                  {message && <div className="alert alert-success">{message}</div>}
                  {error && <div className="alert alert-danger">{error}</div>}

                  <form onSubmit={handleSubmit} encType="multipart/form-data">
                    <div className="row gy-4">
                      {questions.map((q) => (
                        <div key={q.id} className={`col-md-${q.type === 'textarea' ? '12' : '6'}`}>
                          <label className="form-label fw-bold">
                            {q.label} {q.required && <span className="text-danger">*</span>}
                          </label>

                          {q.type === "textarea" && (
                            <textarea
                              name={q.id}
                              required={q.required}
                              maxLength={255}
                              className="form-control"
                            />
                          )}

                          {q.type === "select" && (
                            <select
                              name={q.id}
                              required={q.required}
                              className="form-control form-select"
                            >
                              <option value="">-- اختر --</option>
                              {q.options?.map((opt) => (
                                <option key={opt} value={opt}>
                                  {opt}
                                </option>
                              ))}
                            </select>
                          )}

                          {q.type !== "textarea" && q.type !== "select" && (
                            <input
                              name={q.id}
                              type={q.type}
                              required={q.required}
                              maxLength={255}
                              className="form-control"
                            />
                          )}
                        </div>
                      ))}

                      <div className="col-12">
                        <label className="form-label fw-bold">
                          قم بإرفاق سيرتك الذاتية <span className="text-danger">*</span>
                        </label>
                        <input
                          type="file"
                          accept=".pdf"
                          required
                          className="form-control"
                          onChange={(e) => {
                            if (e.target.files?.[0]) {
                              setFile(e.target.files[0]);
                            }
                          }}
                        />
                      </div>

                      <div className="col-12 text-center">
                        <button type="submit" className="btn btn-success w-100 py-2 fw-bold">
                          تقدم بطلبك الآن
                        </button>
                      </div>
                    </div>
                  </form>
                </div>
              </div>
            </div>
          </div>
        </div>
      </Layout>
    </>
  );
}
